@@ -97,7 +97,7 @@ class Connect:
         self.requested_time = time.time()
         return self.run_code(
             "SELECT %s FROM %s %s;" %
-            ((target and ",".join(target)) or "*", table, condition))
+            ((target and "`" + "`,`".join(target) + "`") or "*", table, condition))
 
     def update(self,
                table,
